@@ -1,9 +1,8 @@
 """
 In this module lives the type tree.
 """
-
-
-from typing import Any, Dict, Optional, Union, Type
+from collections import defaultdict
+from typing import Any, DefaultDict, Dict, List, Optional, Tuple, Type, Union
 
 
 import numpy as np
@@ -16,6 +15,9 @@ CATEGORICAL_NUMPY_DTYPES = [np.bool, np.object]
 CATEGORICAL_PANDAS_DTYPES = [pd.CategoricalDtype, pd.PeriodDtype]
 CATEGORICAL_DTYPES = CATEGORICAL_NUMPY_DTYPES + CATEGORICAL_PANDAS_DTYPES
 
+STRING_PANDAS_DTYPES = [pd.StringDtype]
+STRING_DTYPES = STRING_PANDAS_DTYPES
+
 NUMERICAL_NUMPY_DTYPES = [np.number]
 NUMERICAL_DTYPES = NUMERICAL_NUMPY_DTYPES
 
@@ -257,6 +259,17 @@ def is_pandas_categorical(dtype: Any) -> bool:
     return any(isinstance(dtype, c) for c in CATEGORICAL_PANDAS_DTYPES)
 
 
+def string_dtype_to_object(df: dd.DataFrame) -> dd.DataFrame:
+    """
+    Convert string dtype to object dtype
+    """
+    for col in df.columns:
+        if any(isinstance(df[col].dtype, c) for c in STRING_DTYPES):
+            df[col] = df[col].astype(object)
+
+    return df
+
+
 def drop_null(
     var: Union[dd.Series, pd.DataFrame, dd.DataFrame]
 ) -> Union[pd.Series, dd.Series, pd.DataFrame, dd.DataFrame]:
@@ -279,3 +292,26 @@ def drop_null(
         return df
 
     raise ValueError("Input should be a Pandas/Dask Dataframe or Series")
+
+
+def get_dtype_cnts_and_num_cols(
+    df: dd.DataFrame,
+    dtype: Union[Dict[str, Union[DType, Type[DType], str]], DType, Type[DType], None],
+) -> Tuple[Dict[str, int], List[str]]:
+    """
+    Get the count of each dtype in a dataframe
+    """
+    dtype_cnts: DefaultDict[str, int] = defaultdict(int)
+    num_cols: List[str] = []
+    for col in df.columns:
+        col_dtype = detect_dtype(df[col], dtype)
+        if is_dtype(col_dtype, Nominal()):
+            dtype_cnts["Categorical"] += 1
+        elif is_dtype(col_dtype, Continuous()):
+            dtype_cnts["Numerical"] += 1
+            num_cols.append(col)
+        elif is_dtype(col_dtype, DateTime()):
+            dtype_cnts["DateTime"] += 1
+        else:
+            raise NotImplementedError
+    return dtype_cnts, num_cols
